Class: Google::Cloud::ApigeeConnect::V1::Payload
- Inherits:
-
Object
- Object
- Google::Cloud::ApigeeConnect::V1::Payload
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/apigeeconnect/v1/tether.rb
Overview
Payload for EgressRequest.
Instance Attribute Summary collapse
-
#action ⇒ ::Google::Cloud::ApigeeConnect::V1::Action
The action taken by agent.
-
#http_request ⇒ ::Google::Cloud::ApigeeConnect::V1::HttpRequest
The HttpRequest proto.
-
#stream_info ⇒ ::Google::Cloud::ApigeeConnect::V1::StreamInfo
The information of stream.
Instance Attribute Details
#action ⇒ ::Google::Cloud::ApigeeConnect::V1::Action
Returns The action taken by agent.
Note: The following fields are mutually exclusive: action, http_request, stream_info. If a field in that set is populated, all other fields in the set will automatically be cleared.
65 66 67 68 |
# File 'proto_docs/google/cloud/apigeeconnect/v1/tether.rb', line 65 class Payload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#http_request ⇒ ::Google::Cloud::ApigeeConnect::V1::HttpRequest
Returns The HttpRequest proto.
Note: The following fields are mutually exclusive: http_request, stream_info, action. If a field in that set is populated, all other fields in the set will automatically be cleared.
65 66 67 68 |
# File 'proto_docs/google/cloud/apigeeconnect/v1/tether.rb', line 65 class Payload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#stream_info ⇒ ::Google::Cloud::ApigeeConnect::V1::StreamInfo
Returns The information of stream.
Note: The following fields are mutually exclusive: stream_info, http_request, action. If a field in that set is populated, all other fields in the set will automatically be cleared.
65 66 67 68 |
# File 'proto_docs/google/cloud/apigeeconnect/v1/tether.rb', line 65 class Payload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |